% This file verifies the sum: \sum_{n\in\mathbbm{Z}} \frac{ (-1)^n\sin\alpha n}{(n-\varepsilon)^2},
% where parameter alpha should be in (-pi,+pi). To ensure verification in all possible cases,
% parameters alpha and epsilon are randomly chosen in the specified intervals. 
% The calculation is carried out in 2 different ways: brute numerical summation 
% and exact residue-based method, respectively denoted by answ1 and answ2.
%
% Author: Iaroslav V. Blagouchine, first version of this file was written in July 2010.  


function [answ1,answ2]=sum300313cin(alfa,eps,nmax)

if nargin<3
	nmax=1e3;
end

if nargin<2
	eps=3*rand
end

if nargin<1
	alfa=(2*rand-1)*pi
end


% Computation via direct numeric summation
n=-nmax:nmax;
fn=((-1).^n).*sin(alfa*n)./(n-eps).^2;
answ1=sum(fn);

% Computaion via analytical method of residues
answ2=(pi*sin(alfa*eps)/sin(pi*eps))*(pi*ctg(pi*eps) - alfa*ctg(alfa*eps));